==> uilite-1.0.47.tgz: package/webpack-build.config.js <==
const path = require('path');
let fs=require("fs");
const HtmlWebpackPlugin = require('html-webpack-plugin');
const MiniCssExtractPlugin = require('mini-css-extract-plugin');
function getProjectData(projectName){
  let currentDir=process.cwd();

  let obj={
   entry:path.join(currentDir,"/src/main.ts"),
   buildPath:path.join(currentDir, 'build'),
   staticDir:"public",
   staticPath:[{directory:path.join(currentDir,"public")}],
   template:path.join(currentDir,'build/index.html'),
   port:"5502", 
   bundleFileName:"bundle.js"
  } 
  if(projectName){
   let projectJson=JSON.parse(fs.readFileSync(process.cwd()+"/project.json"));
   let projectData=projectJson[projectName];
    if(projectData?.entry){
     obj.entry=path.join(currentDir,projectData.entry);
    }
    if(projectData?.build_path){
     obj.buildPath=path.join(currentDir, projectData.build_path)
    }
    if(projectData?.static_path){
     obj.template= path.join(currentDir,projectData.static_path+'/index.html')
     obj.staticDir=path.join(currentDir,projectData.static_path)
     obj.staticPath=[{directory:path.join(currentDir,projectData.static_path)}]
    }
    if(projectData?.port){
      obj.port=projectData.port;
    }
    if(projectData?.bundel_file_name){
      obj.bundleFileName=projectData.bundel_file_name
    }
  }
 return obj;
}
module.exports=env => {
 let {entry,buildPath,port,staticDir,template,bundleFileName} =getProjectData(env.project);
 return {
   mode:"production",
  entry: entry,
  module: {
      rules: [
        {
          test: /\.ts?$/,
          use: 'ts-loader',
          exclude: /node_modules/,
        },
        {
          test: /\.html$/i,
          rules:[{
                loader: "val-loader",
                options: {
                  executableFile: path.resolve(
                    __dirname,
                    "importHtml.js"
                  ),
                },
          }]
        },
        {
          test: /\.(s(a|c)ss)$/,
          use: [MiniCssExtractPlugin.loader,'css-loader', 'sass-loader']
        },
        {
          test: /\.(woff|woff2|eot|ttf|svg|jpg|png)$/,
          use: {
            loader: 'url-loader',
          },
        },
      ],
    },
    resolve: {
      extensions: [ '.tsx', '.ts', '.js' ],
    },
    output: {
      filename: bundleFileName,
      path: buildPath,
    },
    plugins: [
      new MiniCssExtractPlugin(),
      new HtmlWebpackPlugin({
        inject: true,
        template: template,
      }),
    ]
  }
};

==> uilite-1.0.65.tgz: package/webpack-build.config.js <==
const path = require('path');
let webpack=require("webpack");
let fs=require("fs");
const HtmlWebpackPlugin = require('html-webpack-plugin');
const MiniCssExtractPlugin = require('mini-css-extract-plugin');
function getProjectData(projectName){
  let currentDir=process.cwd();

  let obj={
   entry:path.join(currentDir,"/src/main.ts"),
   buildPath:path.join(currentDir, 'build'),
   staticDir:"public",
   staticPath:[{directory:path.join(currentDir,"public")}],
   template:path.join(currentDir,'build/index.html'),
   port:"5502", 
   bundleFileName:"bundle.js",
   env:path.join(currentDir,"public/.env")
  } 
  if(projectName){
   let projectJson=JSON.parse(fs.readFileSync(process.cwd()+"/project.json"));
   let projectData=projectJson[projectName];
    if(projectData?.entry){
     obj.entry=path.join(currentDir,projectData.entry);
    }
    if(projectData?.build_path){
     obj.buildPath=path.join(currentDir, projectData.build_path)
    }
    if(projectData?.static_path){
     obj.template= path.join(currentDir,projectData.static_path+'/index.html')
     obj.staticDir=path.join(currentDir,projectData.static_path)
     obj.staticPath=[{directory:path.join(currentDir,projectData.static_path)}]
    }
    if(projectData?.port){
      obj.port=projectData.port;
    }
    if(projectData?.bundel_file_name){
      obj.bundleFileName=projectData.bundel_file_name
    }
    if(projectData?.env){
      obj.env=path.join(currentDir,projectData.env);
    }
  }
 return obj;
}
module.exports=wenv => {
 let {entry,buildPath,port,staticDir,template,bundleFileName,env} =getProjectData(wenv.project);
 let envObj="{}"
 try{
   envObj=fs.readFileSync(env,"utf-8");
 }
 catch(err){
   envObj="{}"
 }
 return {
   mode:"production",
  entry: entry,
  module: {
      rules: [
        {
          test: /\.ts?$/,
          use: 'ts-loader',
          exclude: /node_modules/,
        },
        {
          test: /\.html$/i,
          rules:[{
                loader: "val-loader",
                options: {
                  executableFile: path.resolve(
                    __dirname,
                    "importHtml.js"
                  ),
                },
          }]
        },
        {
          test: /\.(s(a|c)ss)$/,
          use: [MiniCssExtractPlugin.loader,'css-loader', 'sass-loader']
        },
        {
          test: /\.(woff|woff2|eot|ttf|svg|jpg|png)$/,
          use: {
            loader: 'url-loader',
          },
        },
      ],
    },
    resolve: {
      extensions: [ '.tsx', '.ts', '.js' ],
    },
    output: {
      filename: bundleFileName,
      path: buildPath,
    },
    plugins: [
      new webpack.DefinePlugin({
        "process.env": envObj
      }),
      new MiniCssExtractPlugin(),
      new HtmlWebpackPlugin({
        inject: true,
        template: template,
      }),
    ]
  }
};
